import "../chunk-TSCDX4AS.js";
import "../chunk-DSENWI6W.js";
import "../chunk-D6B6MYVG.js";
import "../chunk-NEFIJY6U.js";
import "../chunk-EW6FHLFK.js";
import "../chunk-2VA3UGW7.js";
import "../chunk-BMPLIZZN.js";
import "../chunk-MMY72EVL.js";
import "../chunk-QAMZSJ27.js";
import "../chunk-5OVSRAPG.js";
import "../chunk-OSX4VQOR.js";
import "../chunk-7QYVSWCZ.js";
import "../chunk-OC6HNIEN.js";
import "../chunk-BORRWM4T.js";
import {
  useDefer,
  useDispose
} from "../chunk-TRCJY7KG.js";
import {
  sleep
} from "../chunk-L324TYGN.js";
import "../chunk-K7Z2KDW3.js";
import "../chunk-GY34N3KU.js";
import "../chunk-QUKKMPRF.js";
import {
  DefaultLogger
} from "../chunk-XYJV3SSU.js";
import "../chunk-JZBMDET5.js";
import "../chunk-BFL67QFN.js";
import "../chunk-MFUX7YH7.js";
import "../chunk-MTV32UFZ.js";
import "../chunk-I45WP5PM.js";
import "../chunk-NNCJ3QL5.js";
import "../chunk-MIZOLME5.js";
import "../chunk-AQUNU3KH.js";
import "../chunk-YX6CL4KH.js";
import "../chunk-CFICINSP.js";
import "../chunk-V5ZQ2SFQ.js";
import "../chunk-UOAPXGA4.js";
import "../chunk-EAYWSLQT.js";
import {
  __callDispose,
  __using
} from "../chunk-I7BWSAN6.js";

// src/common/dispose-defer.spec.ts
var log = DefaultLogger("dispose-test");
describe("dispose", () => {
  it("should dispose correctly", async () => {
    const disposeCalls = [];
    const dispose = useDispose("a");
    const y = dispose.track({
      dispose() {
        disposeCalls.push(1);
      }
    });
    dispose.track(() => {
      disposeCalls.push(2);
    });
    const x = {
      async dispose() {
        disposeCalls.push(3);
      }
    };
    dispose.track(x);
    dispose.track();
    dispose.track(async () => {
      disposeCalls.push(4);
    });
    expect(disposeCalls).toEqual([]);
    expect(dispose.getSize()).toEqual(4);
    await dispose.untrack(x);
    expect(disposeCalls).toEqual([3]);
    expect(dispose.getSize()).toEqual(3);
    await dispose.untrack(x);
    expect(disposeCalls).toEqual([3]);
    expect(dispose.getSize()).toEqual(3);
    y?.();
    y?.();
    await dispose.untrack(x);
    expect(disposeCalls).toEqual([3, 1]);
    expect(dispose.getSize()).toEqual(2);
    await dispose.dispose();
    expect(disposeCalls).toEqual([3, 1, 4, 2]);
    expect(dispose.getSize()).toEqual(0);
    await dispose();
    expect(disposeCalls).toEqual([3, 1, 4, 2]);
    expect(dispose.getSize()).toEqual(0);
  });
  it("should be a fancy dispose itself", () => {
    let x = 1;
    class Some {
      constructor() {
        this.dispose = useDispose(log);
        this.dispose.track(() => {
          x = 2;
        });
      }
    }
    const obj = new Some();
    expect(x).toBe(1);
    void obj.dispose();
    expect(x).toBe(2);
  });
  it("should defer lifo", async () => {
    const stack = [];
    const defer = useDefer({ mode: "lifo" });
    defer.add(() => stack.push("a"));
    defer.add(() => stack.push("b"));
    defer.add(() => stack.push("c"));
    expect(stack).toEqual([]);
    void defer(true);
    expect(stack).toEqual(["c", "b", "a"]);
  });
  it("should defer fifo", async () => {
    const stack = [];
    const defer = useDefer({ mode: "fifo" });
    defer.add(() => stack.push("a"));
    defer.add(async () => stack.push("b"));
    defer.add(() => stack.push("c"));
    expect(stack).toEqual([]);
    await defer();
    expect(stack).toEqual(["a", "b", "c"]);
  });
  it("should dispose sync", async () => {
    const stack = [];
    const dispose = useDispose();
    dispose.add(() => stack.push("a"));
    dispose.add(() => stack.push("b"));
    dispose.add(() => stack.push("c"));
    expect(stack).toEqual([]);
    await dispose(true);
    expect(stack).toEqual(["c", "b", "a"]);
  });
  it("should dispose sync using using", async () => {
    const stack = [];
    function helper() {
      var _stack = [];
      try {
        const dispose = __using(_stack, useDispose());
        dispose.add(() => stack.push("a"));
        dispose.add(() => stack.push("b"));
        dispose.add(() => stack.push("c"));
        expect(stack).toEqual([]);
      } catch (_) {
        var _error = _, _hasError = true;
      } finally {
        __callDispose(_stack, _error, _hasError);
      }
    }
    helper();
    expect(stack).toEqual(["c", "b", "a"]);
  });
  it("should dispose sync 2", async () => {
    const stack = [];
    const dispose = useDispose();
    dispose.add(() => stack.push("a"));
    dispose.add(() => stack.push("b"));
    dispose.add(async () => {
      await sleep(1);
      stack.push("c");
    });
    expect(stack).toEqual([]);
    expect(dispose.sync).toThrowError();
  });
  it("should use using", async () => {
    const history = [];
    function log2(s) {
      history.push(s);
    }
    class TempFile {
      constructor(path) {
        log2("constructor");
      }
      [Symbol.dispose]() {
        log2("dispose");
      }
    }
    function fn() {
      var _stack = [];
      try {
        const f = __using(_stack, new TempFile("abc"));
        log2("fn return");
      } catch (_) {
        var _error = _, _hasError = true;
      } finally {
        __callDispose(_stack, _error, _hasError);
      }
    }
    log2("fn before");
    fn();
    log2("fn after");
    expect(history).toMatchInlineSnapshot(`
      Array [
        "fn before",
        "constructor",
        "fn return",
        "dispose",
        "fn after",
      ]
    `);
  });
});
//# sourceMappingURL=dispose-defer.spec.js.map