import {
  parseSchemaEnv,
  stringFromSchemaEnv
} from "../../chunk-Z5POCQXD.js";
import "../../chunk-HIX6EHLQ.js";
import {
  boolean,
  number,
  object,
  string
} from "../../chunk-RSB2DP4K.js";
import "../../chunk-MDMGQSBC.js";
import "../../chunk-XOAKJFNZ.js";
import "../../chunk-NEFIJY6U.js";
import "../../chunk-CDC2UKQU.js";
import "../../chunk-XYJV3SSU.js";
import "../../chunk-JZBMDET5.js";
import "../../chunk-BFL67QFN.js";
import "../../chunk-MTV32UFZ.js";
import "../../chunk-MIZOLME5.js";
import "../../chunk-AQUNU3KH.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-V5ZQ2SFQ.js";
import "../../chunk-UOAPXGA4.js";
import "../../chunk-EAYWSLQT.js";
import "../../chunk-I7BWSAN6.js";

// src/common/schema/env.spec.ts
describe("env.spec", () => {
  it("parse env", async () => {
    const schema = object({
      ServiceName: string().default("generic"),
      servicePort: number().default(80),
      ServiceFlag: boolean().default(true)
    });
    const r = parseSchemaEnv(schema, {
      SERVICE_NAME: "SomeThing",
      SERVICE_PORT: " 8888 ",
      SERVICE_FLAG: "illegalValueTriggerDefault"
    });
    expect(r).toMatchInlineSnapshot(`
      Object {
        "ServiceFlag": true,
        "ServiceName": "SomeThing",
        "servicePort": 8888,
      }
    `);
  });
  it("parse prefix", async () => {
    const schema = object({
      ServiceName: string().default("generic"),
      servicePort: number().default(80),
      ServiceFlag: boolean().default(true)
    });
    const r = parseSchemaEnv(schema, {
      SERVICE_NAME: "SomeThing",
      SERVICE_PORT: " 8888 ",
      APP_SERVICE_PORT: " 9999",
      SERVICE_FLAG: "illegalValueTriggerDefault"
    }, "APP_");
    expect(r).toMatchInlineSnapshot(`
      Object {
        "ServiceFlag": true,
        "ServiceName": "generic",
        "servicePort": 9999,
      }
    `);
    expect(stringFromSchemaEnv(schema, "APP_", true)).toMatchInlineSnapshot(`
      "# APP_SERVICE_NAME=generic
      # APP_SERVICE_PORT=80
      # APP_SERVICE_FLAG=true"
    `);
  });
});
//# sourceMappingURL=env.spec.js.map